@@ -1,25 +1,30 @@
-# MySQL Connector/Python - MySQL driver written in Python.
-# Copyright (c) 2014, 2015, Oracle and/or its affiliates. All rights reserved.
-
-# MySQL Connector/Python is licensed under the terms of the GPLv2
-# <http://www.gnu.org/licenses/old-licenses/gpl-2.0.html>, like most
-# MySQL Connectors. There are special exceptions to the terms and
-# conditions of the GPLv2 as it is applied to this software, see the
-# FOSS License Exception
-# <http://www.mysql.com/about/legal/licensing/foss-exception.html>.
+# Copyright (c) 2014, 2018, Oracle and/or its affiliates. All rights reserved.
 #
 # This program is free software; you can redistribute it and/or modify
-# it under the terms of the GNU General Public License as published by
-# the Free Software Foundation.
+# it under the terms of the GNU General Public License, version 2.0, as
+# published by the Free Software Foundation.
 #
-# This program is distributed in the hope that it will be useful,
-# but WITHOUT ANY WARRANTY; without even the implied warranty of
-# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-# GNU General Public License for more details.
+# This program is also distributed with certain software (including
+# but not limited to OpenSSL) that is licensed under separate terms,
+# as designated in a particular file or component or in included license
+# documentation.  The authors of MySQL hereby grant you an
+# additional permission to link the program and your derivative works
+# with the separately licensed software that they have included with
+# MySQL.
+#
+# Without limiting anything contained in the foregoing, this file,
+# which is part of MySQL Connector/Python, is also subject to the
+# Universal FOSS Exception, version 1.0, a copy of which can be found at
+# http://oss.oracle.com/licenses/universal-foss-exception.
+#
+# This program is distributed in the hope that it will be useful, but
+# WITHOUT ANY WARRANTY; without even the implied warranty of
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
+# See the GNU General Public License, version 2.0, for more details.
 #
 # You should have received a copy of the GNU General Public License
-# along with this program; if not, write to the Free Software
-# Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA
+# along with this program; if not, write to the Free Software Foundation, Inc.,
+# 51 Franklin St, Fifth Floor, Boston, MA 02110-1301  USA
 
 """Connection class using the C Extension
 """
@@ -36,8 +41,9 @@ from .abstracts import MySQLConnectionAbstract, MySQLCursorAbstract
 from .protocol import MySQLProtocol
 
 HAVE_CMYSQL = False
+# pylint: disable=F0401,C0413
 try:
-    import _mysql_connector  # pylint: disable=F0401
+    import _mysql_connector
     from .cursor_cext import (
         CMySQLCursor, CMySQLCursorRaw,
         CMySQLCursorBuffered, CMySQLCursorBufferedRaw, CMySQLCursorPrepared,
@@ -51,6 +57,7 @@ except ImportError as exc:
         ))
 else:
     HAVE_CMYSQL = True
+# pylint: enable=F0401,C0413
 
 
 class CMySQLConnection(MySQLConnectionAbstract):
@@ -63,12 +70,11 @@ class CMySQLConnection(MySQLConnectionAbstract):
             raise RuntimeError(
                 "MySQL Connector/Python C Extension not available")
         self._cmysql = None
-        self._connection_timeout = 2
         self._columns = []
         self.converter = None
         super(CMySQLConnection, self).__init__(**kwargs)
 
-        if len(kwargs) > 0:
+        if kwargs:
             self.connect(**kwargs)
 
     def _do_handshake(self):
@@ -138,12 +144,11 @@ class CMySQLConnection(MySQLConnectionAbstract):
 
     def _open_connection(self):
         charset_name = CharacterSet.get_info(self._charset_id)[0]
-
-        self._cmysql = _mysql_connector.MySQL(
+        self._cmysql = _mysql_connector.MySQL(  # pylint: disable=E1101,I1101
             buffered=self._buffered,
             raw=self._raw,
             charset_name=charset_name,
-            connection_timeout=int(self._connection_timeout or 10),
+            connection_timeout=(self._connection_timeout or 0),
             use_unicode=self._use_unicode,
             auth_plugin=self._auth_plugin)
 
@@ -158,12 +163,13 @@ class CMySQLConnection(MySQLConnectionAbstract):
             'compress': self.isset_client_flag(ClientFlag.COMPRESS)
         }
 
-        if self.isset_client_flag(ClientFlag.SSL):
+        if not self._ssl_disabled:
             cnx_kwargs.update({
-                'ssl_ca': self._ssl['ca'],
-                'ssl_cert': self._ssl['cert'],
-                'ssl_key': self._ssl['key'],
-                'ssl_verify_cert': self._ssl['verify_cert']
+                'ssl_ca': self._ssl.get('ca'),
+                'ssl_cert': self._ssl.get('cert'),
+                'ssl_key': self._ssl.get('key'),
+                'ssl_verify_cert': self._ssl.get('verify_cert') or False,
+                'ssl_disabled': self._ssl_disabled
             })
 
         try:
@@ -177,6 +183,7 @@ class CMySQLConnection(MySQLConnectionAbstract):
         """Disconnect from the MySQL server"""
         if self._cmysql:
             try:
+                self.free_result()
                 self._cmysql.close()
             except MySQLInterfaceError as exc:
                 raise errors.get_mysql_exception(msg=exc.msg, errno=exc.errno,
@@ -210,7 +217,7 @@ class CMySQLConnection(MySQLConnectionAbstract):
         try:
             connected = self._cmysql.ping()
         except AttributeError:
-          pass  # Raise or reconnect later
+            pass  # Raise or reconnect later
         else:
             if connected:
                 return
@@ -249,11 +256,14 @@ class CMySQLConnection(MySQLConnectionAbstract):
 
         return None
 
-    def get_rows(self, count=None, binary=False, columns=None):
+    def get_rows(self, count=None, binary=False, columns=None, raw=None):
         """Get all or a subset of rows returned by the MySQL server"""
         if not (self._cmysql and self.unread_result):
             raise errors.InternalError("No result set available")
 
+        if raw is None:
+            raw = self._raw
+
         rows = []
         if count is not None and count <= 0:
             raise AttributeError("count should be 1 or higher, or None")
@@ -262,31 +272,41 @@ class CMySQLConnection(MySQLConnectionAbstract):
         try:
             row = self._cmysql.fetch_row()
             while row:
-                if self.converter:
+                if not self._raw and self.converter:
                     row = list(row)
                     for i, _ in enumerate(row):
-                        row[i] = self.converter.to_python(self._columns[i],
-                                                          row[i])
+                        if not raw:
+                            row[i] = self.converter.to_python(self._columns[i],
+                                                              row[i])
                     row = tuple(row)
                 rows.append(row)
                 counter += 1
                 if count and counter == count:
                     break
                 row = self._cmysql.fetch_row()
+            if not row:
+                _eof = self.fetch_eof_columns()['eof']
+                self.free_result()
+            else:
+                _eof = None
         except MySQLInterfaceError as exc:
             self.free_result()
             raise errors.get_mysql_exception(msg=exc.msg, errno=exc.errno,
                                              sqlstate=exc.sqlstate)
 
-        return rows
+        return rows, _eof
 
-    def get_row(self, binary=False, columns=None):
+    def get_row(self, binary=False, columns=None, raw=None):
         """Get the next rows returned by the MySQL server"""
         try:
-            return self.get_rows(count=1, binary=binary, columns=columns)[0]
+            rows, eof = self.get_rows(count=1, binary=binary, columns=columns,
+                                      raw=raw)
+            if rows:
+                return (rows[0], eof)
+            return (None, eof)
         except IndexError:
             # No row available
-            return None
+            return (None, None)
 
     def next_result(self):
         """Reads the next result"""
@@ -359,10 +379,11 @@ class CMySQLConnection(MySQLConnectionAbstract):
 
         return None
 
-    def cmd_query(self, query, raw=False, buffered=False, raw_as_string=False):
+    def cmd_query(self, query, raw=None, buffered=False, raw_as_string=False):
         """Send a query to the MySQL server"""
         self.handle_unread_result()
-
+        if raw is None:
+            raw = self._raw
         try:
             if not isinstance(query, bytes):
                 query = query.encode('utf-8')
@@ -523,7 +544,7 @@ class CMySQLConnection(MySQLConnectionAbstract):
         self._cmysql.consume_result()
 
     def cmd_change_user(self, username='', password='', database='',
-                        charset=33):
+                        charset=45):
         """Change the current logged in user"""
         try:
             self._cmysql.change_user(username, password, database)
