@@ -1,25 +1,30 @@
-# MySQL Connector/Python - MySQL driver written in Python.
-# Copyright (c) 2012, 2017, Oracle and/or its affiliates. All rights reserved.
-
-# MySQL Connector/Python is licensed under the terms of the GPLv2
-# <http://www.gnu.org/licenses/old-licenses/gpl-2.0.html>, like most
-# MySQL Connectors. There are special exceptions to the terms and
-# conditions of the GPLv2 as it is applied to this software, see the
-# FOSS License Exception
-# <http://www.mysql.com/about/legal/licensing/foss-exception.html>.
+# Copyright (c) 2012, 2018, Oracle and/or its affiliates. All rights reserved.
 #
 # This program is free software; you can redistribute it and/or modify
-# it under the terms of the GNU General Public License as published by
-# the Free Software Foundation.
+# it under the terms of the GNU General Public License, version 2.0, as
+# published by the Free Software Foundation.
 #
-# This program is distributed in the hope that it will be useful,
-# but WITHOUT ANY WARRANTY; without even the implied warranty of
-# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-# GNU General Public License for more details.
+# This program is also distributed with certain software (including
+# but not limited to OpenSSL) that is licensed under separate terms,
+# as designated in a particular file or component or in included license
+# documentation.  The authors of MySQL hereby grant you an
+# additional permission to link the program and your derivative works
+# with the separately licensed software that they have included with
+# MySQL.
+#
+# Without limiting anything contained in the foregoing, this file,
+# which is part of MySQL Connector/Python, is also subject to the
+# Universal FOSS Exception, version 1.0, a copy of which can be found at
+# http://oss.oracle.com/licenses/universal-foss-exception.
+#
+# This program is distributed in the hope that it will be useful, but
+# WITHOUT ANY WARRANTY; without even the implied warranty of
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
+# See the GNU General Public License, version 2.0, for more details.
 #
 # You should have received a copy of the GNU General Public License
-# along with this program; if not, write to the Free Software
-# Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA
+# along with this program; if not, write to the Free Software Foundation, Inc.,
+# 51 Franklin St, Fifth Floor, Boston, MA 02110-1301  USA
 
 """Module implementing low-level socket communication with MySQL servers.
 """
@@ -124,6 +129,9 @@ class BaseMySQLSocket(object):
         except (socket.error, AttributeError):
             pass
 
+    def __del__(self):
+        self.shutdown()
+
     def send_plain(self, buf, packet_number=None,
                    compressed_packet_number=None):
         """Send packets to the MySQL server"""
@@ -168,9 +176,9 @@ class BaseMySQLSocket(object):
                 tmpbuf = bytearray()
                 for pkt in pkts:
                     tmpbuf += pkt
-                tmpbuf = buffer(tmpbuf)  # pylint: disable=E0602,R0204
+                tmpbuf = buffer(tmpbuf)  # pylint: disable=E0602
             else:
-                tmpbuf = b''.join(pkts)  # pylint: disable=R0204
+                tmpbuf = b''.join(pkts)
             del pkts
             zbuf = zlib.compress(tmpbuf[:16384])
             header = (struct.pack('<I', len(zbuf))[0:3]
@@ -351,7 +359,7 @@ class BaseMySQLSocket(object):
                 while len(zip_payload) < zip_payload_length:
                     chunk = self.sock.recv(zip_payload_length
                                            - len(zip_payload))
-                    if len(chunk) == 0:
+                    if not chunk:
                         raise errors.InterfaceError(errno=2013)
                     zip_payload = zip_payload + chunk
 
@@ -403,7 +411,8 @@ class BaseMySQLSocket(object):
         self._connection_timeout = timeout
 
     # pylint: disable=C0103
-    def switch_to_ssl(self, ca, cert, key, verify_cert=False, cipher=None):
+    def switch_to_ssl(self, ca, cert, key, verify_cert=False, cipher=None,
+                      ssl_version=None):
         """Switch the socket to use SSL"""
         if not self.sock:
             raise errors.InterfaceError(errno=2048)
@@ -414,10 +423,16 @@ class BaseMySQLSocket(object):
             else:
                 cert_reqs = ssl.CERT_NONE
 
-            self.sock = ssl.wrap_socket(
-                self.sock, keyfile=key, certfile=cert, ca_certs=ca,
-                cert_reqs=cert_reqs, do_handshake_on_connect=False,
-                ssl_version=ssl.PROTOCOL_TLSv1, ciphers=cipher)
+            if ssl_version is None:
+                self.sock = ssl.wrap_socket(
+                    self.sock, keyfile=key, certfile=cert, ca_certs=ca,
+                    cert_reqs=cert_reqs, do_handshake_on_connect=False,
+                    ciphers=cipher)
+            else:
+                self.sock = ssl.wrap_socket(
+                    self.sock, keyfile=key, certfile=cert, ca_certs=ca,
+                    cert_reqs=cert_reqs, do_handshake_on_connect=False,
+                    ssl_version=ssl_version, ciphers=cipher)
             self.sock.do_handshake()
         except NameError:
             raise errors.NotSupportedError(
@@ -447,7 +462,8 @@ class MySQLUnixSocket(BaseMySQLSocket):
 
     def open_connection(self):
         try:
-            self.sock = socket.socket(socket.AF_UNIX, socket.SOCK_STREAM)
+            self.sock = socket.socket(socket.AF_UNIX, # pylint: disable=E1101
+                                      socket.SOCK_STREAM)
             self.sock.settimeout(self._connection_timeout)
             self.sock.connect(self.unix_socket)
         except IOError as err:
