@@ -362,10 +362,14 @@ class Protocol(object):
         Returns:
             list: A list of ``mysqlx.protobuf.Message`` objects.
         """
-        count = len(stmt.get_binding_map())
-        scalars = count * [None]
+        bindings = stmt.get_bindings()
         binding_map = stmt.get_binding_map()
-        for binding in stmt.get_bindings():
+        count = len(binding_map)
+        scalars = count * [None]
+        if count != len(bindings):
+            raise ProgrammingError("The number of bind parameters and "
+                                   "placeholders do not match")
+        for binding in bindings:
             name = binding["name"]
             if name not in binding_map:
                 raise ProgrammingError("Unable to find placeholder for "
@@ -584,9 +588,10 @@ class Protocol(object):
         """
         msg = self._reader.read_message()
         if msg.type == "Mysqlx.Error":
-            raise InterfaceError(msg["msg"])
+            raise InterfaceError("Mysqlx.Error: {}".format(msg["msg"]))
         if msg.type != "Mysqlx.Ok":
-            raise InterfaceError("Unexpected message encountered")
+            raise InterfaceError("Unexpected message encountered: {}"
+                                 "".format(msg["msg"]))
 
     def send_connection_close(self):
         """Send connection close."""
@@ -599,3 +604,9 @@ class Protocol(object):
         msg = Message("Mysqlx.Session.Close")
         self._writer.write_message(mysqlxpb_enum(
             "Mysqlx.ClientMessages.Type.SESS_CLOSE"), msg)
+
+    def send_reset(self):
+        """Send reset."""
+        msg = Message("Mysqlx.Session.Reset")
+        self._writer.write_message(mysqlxpb_enum(
+            "Mysqlx.ClientMessages.Type.SESS_RESET"), msg)
